Crate tauri_plugin_shell

Crate tauri_plugin_shell 

Access the system shell. Allows you to spawn child processes and manage files and URLs using their default application.

Modules

openDeprecated
Types and functions related to shell.
process
Types and helpers to spawn and interact with child processes.

Structs

Shell
Access to the shell APIs.

Enums

Error
Errors returned by the shell plugin.

Traits

ShellExt
Extensions to tauri::App, tauri::AppHandle, tauri::WebviewWindow, tauri::Webview and tauri::Window to access the shell APIs.

Functions

init
Initializes the shell plugin.