pub enum Error {
Io(Error),
CurrentExeHasNoParent,
UnknownProgramName(String),
Scope(Error),
SidecarNotAllowed(PathBuf),
ProgramNotAllowed(PathBuf),
UnknownEncoding(String),
Json(Error),
Utf8(FromUtf8Error),
}Expand description
Errors returned by the shell plugin.
Variants
Io(Error)
I/O error, usually raised when spawning a process or reading its output.
CurrentExeHasNoParent
The path of the current executable has no parent directory, so the path of a sidecar program could not be resolved.
UnknownProgramName(String)
The string does not match any of the known programs
accepted by the deprecated open API.
Scope(Error)
The command is not allowed by the configured shell scope.
SidecarNotAllowed(PathBuf)
Sidecar not allowed by the configuration.
ProgramNotAllowed(PathBuf)
Program not allowed by the scope.
UnknownEncoding(String)
The encoding spawn option is neither raw nor a label of a known character encoding.
Json(Error)
JSON error.
Utf8(FromUtf8Error)
Utf8 error.