Module process

Module process 

Types and helpers to spawn and interact with child processes.

Structs

Command
The type to spawn commands.
CommandChild
Spawned child process.
Encoding
An encoding as defined in the Encoding Standard.
ExitStatus
Describes the result of a process after it has terminated.
Output
The output of a finished process.
TerminatedPayload
Payload for the CommandEvent::Terminated command event.

Enums

CommandEvent
A event sent to the command callback.